plone.jsonapi.routes — plone.jsonapi.routes 0.8.3 documentation

### Navigation

- index
- modules |
- next |
- plone.jsonapi.routes 0.8.3 documentation »

# plone.jsonapi.routes

Welcome to plone.jsonapi.routes documentation. This documentation is divided in different parts. I recommend that you get started with Installation and then head over to the Quickstart. Please check out the API documentation for internals about plone.jsonapi.routes.

Table of Contents:

- Installation
  - Buildout
  - JSONView
  - Advanced Rest Client
- Quickstart
  - Environment
  - Version
  - Overview
  - Content Routes
  - Documents
  - Folders
  - Events
  - Files
  - Images
  - Links
  - News Items
  - Topics
  - Collections
- API
  - Concept
  - Base URL
  - Operations
  - Resources
  - Special Resources
  - Parameters
  - Response Format
  - The API Module
- Authentication
  - Login
  - Logout
  - Basic Authentication
- Customizing
  - Adding a custom route provider
  - Adding a custom data adapter
  - Adding a custom data manager
- CRUD
  - Unified API
  - Response Format
  - GET
  - CREATE
  - UPDATE
  - DELETE
  - CUT
  - COPY
  - PASTE
- Dexterity Content
  - Security
- Example
  - Get content by uid
  - Get content by path
  - Get content by parent_path and id
  - Copy/Cut/Paste content
  - Search contents
  - Delete contents
  - Get the portal object
  - Get folder contents
  - Get the full object
- Useful Links
  - Plone
  - plone.jsonapi.routes
  - plone.jsonapi.core
- Contributors
- License
- Changelog
  - 0.8.3 - unreleased
  - 0.8.2 - 2015-09-09
  - 0.8.1 - 2015-09-06
  - 0.8 - 2015-07-20
  - 0.7 - 2015-07-09
  - 0.6 - 2015-02-22
  - 0.5 - 2015-02-20
  - 0.4 - 2015-01-13
  - 0.3 - 2014-10-14
  - 0.2 - 2014-03-05
  - 0.1 - 2014-01-23

### Navigation

- index
- modules |
- next |
- plone.jsonapi.routes 0.8.3 documentation »